
(function($){
	var __isRTL = function(str){
		if(typeof str != typeof "" || str.length<1)
			return false;
		var cc = str.charCodeAt(0);
		if(cc>=1536 && cc<=1791) // arabic, persian, ...
			return true;
		if(cc>=65136 && cc<=65279) // arabic peresent 2
			return true;
		if(cc>=64336 && cc<=65023) // arabic peresent 1
			return true;
		if(cc>=1424 && cc<=1535) // hebrew
			return true;
		if(cc>=64256 && cc<=64335) // hebrew peresent
			return true;
		if(cc>=1792 && cc<=1871) // Syriac
			return true;
		if(cc>=1920 && cc<=1983) // Thaana
			return true;
		if(cc>=1984 && cc<=2047) // NKo
			return true;
		if(cc>=11568 && cc<=11647) // Tifinagh
			return true;
		return false;
	};
	var __fisrt_child = function(par){
		var res=par.firstChild;
		while (res) {
			if (!__is_ignorable(res))
				return res;
			res = res.nextSibling;
		}
		return null;
	};
	var __is_ignorable = function(nod){
		return ( nod.nodeType == 8) || // A comment node
			((nod.nodeType == 3) && __is_all_ws(nod) ); // a text node, all ws
	};
	var __is_all_ws = function(nod){
		return !(/[^\t\n\r ]/.test(nod.data));
	};
	var __node_after = function(sib){
		while ((sib = sib.nextSibling))
			if(!__is_ignorable(sib))
				return sib;
		return null;
	};
	var __firstData = function(p){
		var fc = __fisrt_child(p);
		if(fc!=null && fc.nodeType == 1)
			fc = __firstData(fc);
		if(fc!=null && fc.nodeType == 3)
			return fc;
		fc = __node_after(p);
		while(fc!=null && fc.nodeType == 1){
			fc = __firstData(fc);
			if(fc && fc.nodeType == 3)
				return fc;
			fc = __node_after(fc);
		}
		return false;
	};
	var __node_before = function(sib){
		while ((sib = sib.previousSibling))
			if (!__is_ignorable(sib))
				return sib;
		return null;
	};

	var __lastChild = function(par){
		var res=par.lastChild;
		while (res){
			if(!__is_ignorable(res))
				return res;
			res = res.previousSibling;
		}
		return null;
	};

	var __lastData = function(p){
		var fc = __lastChild(p);
		if(fc!=null && fc.nodeType == 1)
			fc = __lastData(fc);
		if(fc!=null && fc.nodeType == 3)
			return fc;
		fc = __node_before(p);
		while(fc!=null && fc.nodeType == 1){
			fc = __lastData(fc);
			if(fc && fc.nodeType == 3)
				return fc;
			fc = __node_before(fc);
		}
		return false;
	};
	var __data_of = function(txt){
		var data = txt.data;
		// Use ECMA-262 Edition 3 String and RegExp features
		data = data.replace(/[\t\n\r ]+/g, " ");
		if (data.charAt(0) == " ")
			data = data.substring(1, data.length);
		if (data.charAt(data.length - 1) == " ")
			data = data.substring(0, data.length - 1);
		return data;
	};
	$.fn.setDirections = function(op, fromEnd){
		return this.each(
			function(){
				if(fromEnd == true)
					var xStr = __data_of(__lastData(this));
				else
					var xStr = __data_of(__firstData(this));
				if(__isRTL(xStr)){
					if(typeof op == typeof "")
						$(this).addClass(op);
					else if(typeof op == typeof {})
						$(this).css(op);
					else
						this.setAttribute("dir", "rtl");
				}
			}
		);
	};
})(jQuery);

